@@ -23,18 +23,18 @@ import org.apache.doris.flink.deserialization.DorisDeserializationSchema;
 import org.apache.doris.flink.exception.DorisException;
 import org.apache.doris.flink.rest.PartitionDefinition;
 import org.apache.doris.flink.rest.RestService;
+import org.apache.doris.flink.source.reader.DorisValueReader;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.java.typeutils.ResultTypeQueryable;
-import org.apache.flink.calcite.shaded.com.google.common.collect.Lists;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.streaming.api.functions.source.RichParallelSourceFunction;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.util.ArrayList;
 import java.util.List;
 
 
-
 /**
  * DorisSource
  **/
@@ -48,7 +48,7 @@ public class DorisSourceFunction extends RichParallelSourceFunction<List<?>> imp
     private final DorisReadOptions readOptions;
     private transient volatile boolean isRunning;
     private List<PartitionDefinition> dorisPartitions;
-    private List<PartitionDefinition> taskDorisPartitions = Lists.newArrayList();
+    private List<PartitionDefinition> taskDorisPartitions = new ArrayList<>();
 
     public DorisSourceFunction(DorisStreamOptions streamOptions, DorisDeserializationSchema<List<?>> deserializer) {
         this.deserializer = deserializer;
@@ -87,11 +87,13 @@ public class DorisSourceFunction extends RichParallelSourceFunction<List<?>> imp
     @Override
     public void run(SourceContext<List<?>> sourceContext) {
         for (PartitionDefinition partitions : taskDorisPartitions) {
-            try (ScalaValueReader scalaValueReader = new ScalaValueReader(partitions, options, readOptions)) {
-                while (isRunning && scalaValueReader.hasNext()) {
-                    List<?> next = scalaValueReader.next();
+            try (DorisValueReader valueReader = new DorisValueReader(partitions, options, readOptions)) {
+                while (isRunning && valueReader.hasNext()) {
+                    List<?> next = valueReader.next();
                     sourceContext.collect(next);
                 }
+            } catch (Exception e) {
+                logger.error("close reader resource failed,", e);
             }
         }
     }
