@@ -18,9 +18,9 @@ package org.apache.doris.flink.table;
 
 import org.apache.doris.flink.cfg.DorisOptions;
 import org.apache.doris.flink.cfg.DorisReadOptions;
-import org.apache.doris.flink.datastream.ScalaValueReader;
 import org.apache.doris.flink.deserialization.converter.DorisRowConverter;
 import org.apache.doris.flink.rest.PartitionDefinition;
+import org.apache.doris.flink.source.reader.DorisValueReader;
 import org.apache.flink.annotation.Internal;
 import org.apache.flink.api.common.io.DefaultInputSplitAssigner;
 import org.apache.flink.api.common.io.InputFormat;
@@ -30,17 +30,12 @@ import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.java.typeutils.ResultTypeQueryable;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.core.io.InputSplitAssigner;
-import org.apache.flink.table.data.DecimalData;
 import org.apache.flink.table.data.RowData;
-import org.apache.flink.table.data.StringData;
-import org.apache.flink.table.types.logical.DecimalType;
-import org.apache.flink.table.types.logical.LogicalType;
 import org.apache.flink.table.types.logical.RowType;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
-import java.math.BigDecimal;
 import java.sql.PreparedStatement;
 import java.util.ArrayList;
 import java.util.List;
@@ -59,7 +54,7 @@ public class DorisRowDataInputFormat extends RichInputFormat<RowData, DorisTable
     private List<PartitionDefinition> dorisPartitions;
     private TypeInformation<RowData> rowDataTypeInfo;
 
-    private ScalaValueReader scalaValueReader;
+    private DorisValueReader valueReader;
     private transient boolean hasNext;
 
     private final DorisRowConverter rowConverter;
@@ -105,8 +100,8 @@ public class DorisRowDataInputFormat extends RichInputFormat<RowData, DorisTable
      */
     @Override
     public void open(DorisTableInputSplit inputSplit) throws IOException {
-        scalaValueReader = new ScalaValueReader(inputSplit.partition, options, readOptions);
-        hasNext = scalaValueReader.hasNext();
+        valueReader = new DorisValueReader(inputSplit.partition, options, readOptions);
+        hasNext = valueReader.hasNext();
     }
 
     /**
@@ -147,27 +142,13 @@ public class DorisRowDataInputFormat extends RichInputFormat<RowData, DorisTable
         if (!hasNext) {
             return null;
         }
-        List next = (List) scalaValueReader.next();
+        List next = valueReader.next();
         RowData genericRowData = rowConverter.convertInternal(next);
         //update hasNext after we've read the record
-        hasNext = scalaValueReader.hasNext();
+        hasNext = valueReader.hasNext();
         return genericRowData;
     }
 
-    private Object deserialize(LogicalType type, Object val) {
-        switch (type.getTypeRoot()) {
-            case DECIMAL:
-                final DecimalType decimalType = ((DecimalType) type);
-                final int precision = decimalType.getPrecision();
-                final int scala = decimalType.getScale();
-                return DecimalData.fromBigDecimal((BigDecimal) val, precision, scala);
-            case VARCHAR:
-                return StringData.fromString((String) val);
-            default:
-                return val;
-        }
-    }
-
     @Override
     public BaseStatistics getStatistics(BaseStatistics cachedStatistics) throws IOException {
         return cachedStatistics;
@@ -249,7 +230,7 @@ public class DorisRowDataInputFormat extends RichInputFormat<RowData, DorisTable
 
         public DorisRowDataInputFormat build() {
             return new DorisRowDataInputFormat(
-                optionsBuilder.build(), partitions, readOptions, rowType
+                    optionsBuilder.build(), partitions, readOptions, rowType
             );
         }
     }
