@@ -17,46 +17,47 @@
 
 package org.apache.doris.flink;
 
-import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
-import org.apache.flink.table.api.bridge.java.StreamTableEnvironment;
+import org.apache.flink.table.api.EnvironmentSettings;
+import org.apache.flink.table.api.TableEnvironment;
 
 public class DorisSourceSinkExample {
 
     public static void main(String[] args) {
-        final StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        env.setParallelism(1);
-        env.enableCheckpointing(10000);
-        final StreamTableEnvironment tEnv = StreamTableEnvironment.create(env);
+        EnvironmentSettings settings = EnvironmentSettings.newInstance()
+                .inStreamingMode()
+                .build();
+        TableEnvironment tEnv = TableEnvironment.create(settings);
         tEnv.executeSql(
                 "CREATE TABLE doris_test (" +
-                        "id INT," +
                         "name STRING," +
-                        "PRIMARY KEY (id) NOT ENFORCED" +
-                        ") " +
-                        "WITH (\n" +
-                        "  'connector' = 'mysql-cdc',\n" +
-                        "  'hostname' = '127.0.0.1',\n" +
-                        "  'port' = '3306',\n" +
-                        "  'username' = 'root',\n" +
-                        "  'password' = '123456'," +
-                        "  'database-name' = 'test', " +
-                        "  'table-name' = 'test'" +
-                        ")");
-        tEnv.executeSql(
-                "CREATE TABLE doris_test_sink (" +
-                        "id INT," +
-                        "name STRING" +
+                        "age INT," +
+                        "price DECIMAL(5,2)," +
+                        "sale DOUBLE" +
                         ") " +
                         "WITH (\n" +
                         "  'connector' = 'doris',\n" +
-                        "  'fenodes' = '127.0.0.1:8030',\n" +
-                        "  'table.identifier' = 'test.tbk',\n" +
+                        "  'fenodes' = 'FE_IP:8030',\n" +
+                        "  'table.identifier' = 'db.table',\n" +
+                        "  'username' = 'root',\n" +
+                        "  'password' = ''" +
+                        ")");
+        tEnv.executeSql(
+                "CREATE TABLE doris_test_sink (" +
+                        "name STRING," +
+                        "age INT," +
+                        "price DECIMAL(5,2)," +
+                        "sale DOUBLE" +
+                        ") " +
+                        "WITH (\n" +
+                        "  'connector' = 'doris',\n" +
+                        "  'fenodes' = 'FE_IP:8030',\n" +
+                        "  'table.identifier' = 'db.table',\n" +
                         "  'username' = 'root',\n" +
                         "  'password' = '',\n" +
                         "  'sink.properties.format' = 'csv',\n" +
                         "  'sink.label-prefix' = 'doris_csv_table'\n" +
                         ")");
 
-        tEnv.executeSql("INSERT INTO doris_test_sink select id,name from doris_test");
+        tEnv.executeSql("INSERT INTO doris_test_sink select name,age,price,sale from doris_test");
     }
 }
